from setuptools import setup, find_packages

setup(
    name="atsky",
    version="0.0.1",
    author="atsky",
    author_email="9239867+chaos-god@user.noreply.gitee.com",
    description="atsky",
    url="https://gitee.com/chaos-god/atsky.git",
    packages=find_packages(),
    install_requires=[],
    setup_requires=[],
    tests_require=[
        'pytest>=7.1.2',
    ],
    dependency_links=[
    ],
    extras_require={
    }
)
